==> foundry_platform_sdk-0.87.0-py3-none-any.whl: foundry/v2/ontologies/errors/_invalid_parameter_value.py <==
#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from __future__ import annotations

from dataclasses import dataclass
from typing import Literal

import pydantic
from typing_extensions import NotRequired
from typing_extensions import TypedDict

from foundry._errors import PalantirRPCException
from foundry.v2.ontologies.models._data_value import DataValue
from foundry.v2.ontologies.models._ontology_data_type import OntologyDataType
from foundry.v2.ontologies.models._parameter_id import ParameterId
from foundry.v2.ontologies.models._value_type import ValueType


class InvalidParameterValueParameters(TypedDict):
    """
    The value of the given parameter is invalid. See the documentation of `DataValue` for details on
    how parameters are represented.
    """

    __pydantic_config__ = {"extra": "allow"}  # type: ignore

    parameterBaseType: NotRequired[ValueType]

    parameterDataType: NotRequired[OntologyDataType]

    parameterId: ParameterId

    parameterValue: NotRequired[DataValue]


@dataclass
class InvalidParameterValue(PalantirRPCException):
    name: Literal["InvalidParameterValue"]
    parameters: InvalidParameterValueParameters
    error_instance_id: str


__all__ = ["InvalidParameterValue"]

==> foundry_platform_sdk-0.107.0-py3-none-any.whl: foundry/v2/ontologies/errors/_invalid_parameter_value.py <==
#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


import typing
from dataclasses import dataclass

import typing_extensions

from foundry import _errors as errors
from foundry.v2.ontologies import models as ontologies_models


class InvalidParameterValueParameters(typing_extensions.TypedDict):
    """
    The value of the given parameter is invalid. See the documentation of `DataValue` for details on
    how parameters are represented.
    """

    __pydantic_config__ = {"extra": "allow"}  # type: ignore

    parameterBaseType: typing_extensions.NotRequired[ontologies_models.ValueType]
    parameterDataType: typing_extensions.NotRequired[ontologies_models.OntologyDataType]
    parameterId: ontologies_models.ParameterId
    parameterValue: typing_extensions.NotRequired[ontologies_models.DataValue]


@dataclass
class InvalidParameterValue(errors.BadRequestError):
    name: typing.Literal["InvalidParameterValue"]
    parameters: InvalidParameterValueParameters
    error_instance_id: str


__all__ = ["InvalidParameterValue"]
